// ********************************************************************************** //
// The contents of this file are subject to the Mozilla Public License Version 1.1    //
// (the "License"); you may not use this file except in compliance with the License.  //
// You may obtain a copy of the License at http://www.mozilla.org/MPL/                //
//                                                                                    //
// Software distributed under the License is distributed on an "AS IS" basis,         //
// WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License for the  //
// specific language governing rights and limitations under the License.              //
//                                                                                    //
// The Original Code provided by Mozilla's Firefox is XUL, Javascript, and CSS.       // 
// The Initial Developer of the Original Code is Aseem Kishore.                       //
// Portions created by Scott Williamson are Copyright (c) 2006.  All Rights Reserved. //
// Contributor - Intuit Inc. (c) 2007                                                 //
// ********************************************************************************** //

// -- DOMAIN FILTERING -- //
function thumbstrips_trimDomainFromUrl(url)
{
    var retVal = url;
    
//    first try to strip out https://
	if (retVal.substr(0, 8) === "https://") 
	{
	    retVal = retVal.substr(8);
	}
	else if(retVal.substr(0,7) == "http://")
	{
	    retVal = retVal.substr(7);
    }	
    
    if(retVal.substr(0,4)=="www.")
    {
        retVal = retVal.substr(4);
    }
    
    var domainEnd = retVal.indexOf("/");;
    
    if(domainEnd > 0)
        retVal = retVal.substring(0,domainEnd);
              
    return retVal;   
}

function thumbstrips_fillDomains(button) 
{
	// remove the old menu items
	var menu = document.getElementById("thumbstripsDomainFilterPopup");
	
	for (var a = menu.childNodes.length - 1; a > 1; a--) 
	{
		menu.removeChild(menu.childNodes[a]);
	}
	
	
	// cycle through each filmstrip node and put in its domain -- don't repeat
	thumbnailNodes = thumbstrips_GetFilmstrip().m_filmstripManager.m_xmlData.documentElement.selectNodes("//PageThumbnails/PageThumbnail");

	var menuDomains = new Array();
	
	for (var i = 0; i < thumbnailNodes.length; i++) 
	{
		domain = thumbnailNodes[i].getAttribute("Domain");
		
		// use a hash map to preven duplicates, and it's also ordered alphabetically
		menuDomains[domain] = domain;
	}
	
//	all.setAttribute("label", thumbstrips_contentAllLabel);
	
	// then cycle through each domain in the hash map and append it to the menu
	// but first copy it over to maintain alphabetical order
	
	var copyMenuDomains = thumbstrips_propCopy(menuDomains).sort();
	
	for (i = 0; i < copyMenuDomains.length; i++) 
	{
		// if filtering is off, add it to the menu as checked, and don't bother
		// adding it to the currentDomains array
		
		var item = document.createElement("menuitem");
		
		item.setAttribute("label", copyMenuDomains[i]);
		item.setAttribute("type", "checkbox");
		
		if (thumbstrips_domainFiltering === false) 
		{
			item.setAttribute("checked", "false");
		} 
		else 
		{
			if (thumbstrips_currentDomains[copyMenuDomains[i]] === true) 
			{
				item.setAttribute("checked", "true");
			} 
			else 
			{
				item.setAttribute("checked", "false");
			}
		}
		
		// important -- don't have autocheck on because check needs to be read/set manually
		// important -- don't do event.preventBubble() since the button's oncommand
		// is to filter the domains after any change.
		item.setAttribute("autocheck", "false");
		item.setAttribute("oncommand", "thumbstrips_toggleDomain(this);");
		
		menu.appendChild(item);
	}
}

function thumbstrips_selectAllDomains(item) 
{
	if (thumbstrips_domainFiltering === false) 
	{
		return;
	}
	
	thumbstrips_domainFiltering = false;
	thumbstrips_currentDomains = new Array();
	
	var menu = item.parentNode;
	var button = menu.parentNode;
	
	button.setAttribute("label", thumbstrips_contentButtonAllLabel);
	item.setAttribute("checked", "true");
	
	// begin after the all and separator items and uncheck everything
	for (var i = 2; i < menu.childNodes.length; i++) 
	{
		menu.childNodes[i].setAttribute("checked", "false");
	}
	
	var renderer = new thumbstripsFilmstripRenderer();
	renderer.Draw(true);
	renderer = null;
}


function thumbstrips_toggleDomain(item) 
{	
	var menu = item.parentNode; 
	var button = menu.parentNode;
	var all = menu.childNodes[0];
	    
	if (thumbstrips_domainFiltering === false) 
	{   
	    thumbstrips_domainFiltering = true;
		
		var all = menu.childNodes[0];
		
		all.setAttribute("checked", "false");
		button.setAttribute("label", thumbstrips_contentButtonFilteredLabel);
	}
	
	var domain = item.getAttribute("label");
	
	// add/remove it from currentDomains, but don't remove it if it's the only one
	
	if (item.getAttribute("checked") === "true") 
	{
		// assert currentDomains exists and currentDomains[domain] exists and = true
		
		if (thumbstrips_propLength(thumbstrips_currentDomains) <= 1) 
		{
			return;
		}
		
		delete thumbstrips_currentDomains[domain];
		item.setAttribute("checked", "false");
	} 
	else 
	{
		// assert currentDomains exists and currentDomains[domain] doesn't exist or exists and = false
		
		thumbstrips_currentDomains[domain] = true;
		item.setAttribute("checked", "true");
	}
	
	var renderer = new thumbstripsFilmstripRenderer();
	renderer.Draw(true);
	renderer = null;
}