// ********************************************************************************** //
// The contents of this file are subject to the Mozilla Public License Version 1.1    //
// (the "License"); you may not use this file except in compliance with the License.  //
// You may obtain a copy of the License at http://www.mozilla.org/MPL/                //
//                                                                                    //
// Software distributed under the License is distributed on an "AS IS" basis,         //
// WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License for the  //
// specific language governing rights and limitations under the License.              //
//                                                                                    //
// The Original Code provided by Mozilla's Firefox is XUL, Javascript, and CSS.       // 
// The Initial Developer of the Original Code is Aseem Kishore.                       //
// Portions created by Scott Williamson are Copyright (c) 2006.  All Rights Reserved. //
// Contributor - Intuit Inc. (c) 2007                                                 //
// ********************************************************************************** //

// -- INITIALIZATION -- //
var hasBeenOnPageForMinimumTime = false;

/**
 * An object that listens for changes in browser location, preferences, etc.
 */
var thumbstrips_listener = {
	
	// for browser location
	
	QueryInterface: function(aIID) {
		if (aIID.equals(Components.interfaces.nsIWebProgressListener) ||
				aIID.equals(Components.interfaces.nsISupportsWeakReference) ||
				aIID.equals(Components.interfaces.nsISupports)) {
			return this;
		}

		throw Components.results.NS_NOINTERFACE;
	},

	onLocationChange: function(progress, request, uri) 
	{	
        if (document.addEventListener) 
        {    
            document.addEventListener("DOMContentLoaded", HandleContentLoadedEvent, false);
        }
        
        if(uri.asciiHost == "innovation.intuit.com" && uri.spec.match("view=") && uri.spec.match(".film")) 
        {
	    	var url_to_load        = uri.spec;
	    	var remove_current_tab = false;
	    	
	    	if(uri.spec.match("web=yes")) 
	    	{
	    		//alert("setting this to true");
	    		var remove_current_tab = true;
	    	}
	    	
	    	// redirect to a loading page while we're loading the Thumbstrip
	    	var browser = document.getElementById("content");
		    browser.loadURI("chrome://thumbstrips/content/loadingthumbstrip.xul");

            allThumbnailNodes = thumbstrips_GetFilmstrip().m_filmstripManager.m_xmlData.documentElement.selectNodes("//PageThumbnails/PageThumbnail");
            
            if(allThumbnailNodes.length >= 1)		    
			{
				if(confirmAccept() == true) 
				{
	    			//window.open("chrome://thumbstrips/content/loadingdialog.xul", "", "chrome,modal,centerscreen");
	    			thumbstrips_loadFilmstripFromURL(url_to_load, remove_current_tab);
	    			//var browser = document.getElementById("content");
	    			//browser.removeCurrentTab();
		    	}
		    	else 
		    	{
		    		//don't proceed, link back to ii
		    		var browser = document.getElementById("content");
					browser.loadURI("http://innovation.intuit.com/blog/browse-for-thumbstrips");
		    	}	
			}
			else 
			{
				//window.open("chrome://thumbstrips/content/loadingdialog.xul", "", "chrome,modal,centerscreen");
	    		thumbstrips_loadFilmstripFromURL(url_to_load, remove_current_tab);
			}
	    }
	},
	
	onStateChange: function(aProgress, aRequest, aFlag, aStatus) 
	{
		if(aFlag & Components.interfaces.nsIWebProgressListener.STATE_START) 
		{
//			thumbstrips_log("** starting **");
		}
		
		if(aFlag & Components.interfaces.nsIWebProgressListener.STATE_STOP) 
		{
//			thumbstrips_log("** stopping **");
		}
	},
	
	onProgressChange: function() {},
	onStatusChange: function() {},
	onSecurityChange: function() {},
	onLinkIconAvailable: function() {},
	
	// for preferences
	
	observe: function(subject, topic, data) 
	{
		if (topic != "nsPref:changed") 
		{
			return;
		}
		
//		alert("observing preference, data = " + data);
		switch (data) 
		{	
			case "thumbstrips.sorting.first_visit":
			case "thumbstrips.sorting.last_visit":
			case "thumbstrips.sorting.every_visit":
			case "thumbstrips.sorting.manual":
				thumbstrips_setSorting();
				break;
				
			case "thumbstrips.options.pause_switch":
				thumbstrips_setPauseSwitch(thumbstrips_prefs.getBoolPref("options.pause_switch"));
				break;
				
			case "thumbstrips.options.mouse_scroll":
				thumbstrips_setMouseScroll(thumbstrips_prefs.getBoolPref("options.mouse_scroll"));
				break;
				
			default:
//				alert("invalid data");
				// weird bug where options.mouse_scroll is sometimes time.mouse_update_frequency
				thumbstrips_setMouseScroll(thumbstrips_prefs.getBoolPref("options.mouse_scroll"));
		}
	}
};

function HandleContentLoadedEvent()
{       
    var url = GetCurrentUrl();

	// Loading a URL sometimes fires a location change event twice 
	if (url === thumbstrips_currentUrl) 
	{
		return;
	}
	
	thumbstrips_currentUrl = url;
	
	// Don't start recording this page again if it was just deleted
	if (url === thumbstrips_deletedUrl) 
	{
		return;
	}
	
    thumbstrips_deletedUrl = "";
   
    hasBeenOnPageForMinimumTime = false;
    var minimumTimeOnPage = thumbstrips_prefs.getCharPref("recording.minimumTimeOnPage");
    var test = parseFloat(minimumTimeOnPage);
    window.setTimeout(HandleMinimumPageTimeEvent, test * 1000);
        
}

function confirmAccept() 
{
	//var answer = confirm("Viewing this ThumbStrip will overwrite your current ThumbStrip.  Is this ok?\nIf not, click Cancel and save before viewing.")
	var answer = confirm("If you were recording a Thumbstrip, opening this new Thumbstrip will delete it.  Click OK to proceed or Cancel to save before viewing.");
	if (answer)
	{
		return true;
	}
	else
	{
		return false;
	}
}


/**
 * Called when the browser is loaded.
 */
function thumbstrips_load() 
{
	// Initialize overlay variables safely
	thumbstrips_button = document.getElementById("thumbstrips_openButtonOn");
	thumbstrips_tray = document.getElementById("thumbstrips_tray");
	thumbstrips_toolbar = document.getElementById("thumbstrips_toolbar");
	thumbstrips_box = document.getElementById("thumbstrips_box");
	thumbstrips_scrollbox = thumbstrips_box.boxObject.QueryInterface(Components.interfaces.nsIScrollBoxObject);
	thumbstrips_splitter = document.getElementById("thumbstrips_splitter");
	thumbstrips_searchBox = document.getElementById("thumbstrips_searchBox");
		
	// Initialize locale strings
	thumbstrips_getLocaleStrings();
	
	// Initialize preference-based objects safely
	thumbstrips_prefs = Components.classes["@mozilla.org/preferences-service;1"].
			getService(Components.interfaces.nsIPrefService).getBranch("thumbstrips.");
	
	thumbstrips_emptyImage = document.createElementNS("http://www.w3.org/1999/xhtml", "img");
	thumbstrips_emptyImage.src = "chrome://thumbstrips/skin/emptyThumb.png";
	
	// this is an exception in case you want to make a new filmstrip
//	thumbstrips_currentHeight = thumbstrips_prefs.getIntPref("style.default_thumb_height");
	thumbstrips_currentHeight = thumbstrips_currentHeight ? thumbstrips_currentHeight : thumbstrips_prefs.getIntPref("style.default_thumb_height");
	
	// Style the overlay elements safely
	var boxHeight = thumbstrips_currentHeight + thumbstrips_textHeight;
	var boxMinHeight = thumbstrips_prefs.getIntPref("style.thumb_min_height") + thumbstrips_textHeight;
	var boxMaxHeight = thumbstrips_prefs.getIntPref("style.thumb_max_height") + thumbstrips_textHeight;
	
	thumbstrips_box.style.height = boxHeight + "px";
	thumbstrips_box.style.minHeight = boxMinHeight + "px";
//	thumbstrips_box.style.maxHeight = boxMaxHeight + "px";
	
	var toolbarHeight = /*thumbstrips_toolbar.boxObject.height*/34;
	var hiddenHeight = /*thumbstrips_toolbar.boxObject.height*/16;
	
	thumbstrips_tray.style.height = (hiddenHeight + toolbarHeight + boxHeight) + "px";
	thumbstrips_tray.style.minHeight = (hiddenHeight + toolbarHeight + boxMinHeight) + "px";
//	thumbstrips_tray.style.maxHeight = (hiddenHeight + toolbarHeight + boxMaxHeight) + "px";

//	thumbstrips_blurSearch(thumbstrips_searchBox);

	// Initialize the menus
	
	var sortMenu = document.getElementById("thumbstrips_sortMenuPopup");
	var sortManager = new thumbstripsSortManager();
	var sortArray = sortManager.GetSortingPreferences();
	
	// assert sortMenu has exactly three children?
	
	for (var i = 0; i < sortMenu.childNodes.length; i++) 
	{
		if (sortArray[i] === true) 
		{
			sortMenu.childNodes[i].setAttribute("checked", "true");
		}
		else
		{
		    sortMenu.childNodes[i].setAttribute("checked", "false");
		}
	}
	
	sortManager.ShowManualSort(false);
	sortManager = false;
	
	var msMI = document.getElementById("thumbstrips_mouseScrollMenuItem");
	var psMI = document.getElementById("thumbstrips_pauseSwitchMenuItem");
	
	msMI.setAttribute("checked", thumbstrips_prefs.getBoolPref("options.mouse_scroll"));
	psMI.setAttribute("checked", thumbstrips_prefs.getBoolPref("options.pause_switch"));
	
	// Place the view > recording menu item correctly
//	var vrMI = document.getElementById("thumbstrips_viewRecordingMenuItem");
	var vrMI = document.createElement("menuitem");
	
	vrMI.setAttribute("id", "thumbstrips_viewRecordingMenuItem");
	vrMI.setAttribute("label", thumbstrips_recordingStopLabel);
	vrMI.setAttribute("tooltiptext", thumbstrips_recordingStopTooltiptext);
	vrMI.setAttribute("key", "thumbstrips_recordKey1");
	vrMI.setAttribute("oncommand", "thumbstrips_toggleRecording();");
	
	var viewMenu = document.getElementById("menu_viewPopup");
	var reload = viewMenu.getElementsByAttribute("label", "Reload");
	var sep;
	
	if (reload.length >= 1) 
	{
		reload = reload[0];
		reload.setAttribute("id", "reloadMenuItem");
		
		sep = reload.nextSibling;
		sep.setAttribute("id", "separatorMenuItem");
		
		vrMI.setAttribute("insertafter", "reloadMenuItem");
		vrMI.setAttribute("insertbefore", "separatorMenuItem");
		
		viewMenu.insertBefore(vrMI, sep);
	}
		
	// Initialize any global variables
	thumbstrips_currentUrl = "";
	thumbstrips_currentNode = null;
	thumbstrips_deletedUrl = "";
	thumbstrips_recording = true;
	thumbstrips_statusBar = "";
	thumbstrips_domainFiltering = false;
	thumbstrips_currentDomains = new Array();
	//thumbstrips_currentSearchPatterns = new Array();
	thumbstrips_clearSearch(true);
	thumbstrips_mousePause = false;
	
	// Add listeners
	gBrowser.addProgressListener(thumbstrips_listener, Components.interfaces.nsIWebProgress.NOTIFY_STATE_DOCUMENT);
	Components.classes["@mozilla.org/preferences-service;1"].
			getService(Components.interfaces.nsIPrefBranchInternal).addObserver("thumbstrips.", thumbstrips_listener, false);

    var timeUpdateFrequency = thumbstrips_prefs.getIntPref("time.time_update_frequency");
    
    if(timeUpdateFrequency > 60)
    {
        timeUpdateFrequency = 60;
        timeUpdateFrequency = thumbstrips_prefs.getIntPref("time.page_update_frequency"); 
        thumbstrips_prefs.setIntPref("time.page_update_frequency", timeUpdateFrequency);
    }
    
	thumbstrips_timeUpdater = window.setInterval(thumbstrips_updateTimes, timeUpdateFrequency * 1000);

	thumbstrips_box.addEventListener("overflow", thumbstrips_addScrollbar, true);
	thumbstrips_box.addEventListener("underflow", thumbstrips_removeScrollbar, true);
//	thumbstrips_box.addEventListener("overflowchanged", thumbstrips_changeScrollbar, true);
	
	if (thumbstrips_prefs.getBoolPref("options.pause_switch") === true) 
	{
		window.addEventListener("blur", thumbstrips_tempStopRecording, true);
	}
	
	window.addEventListener("blur", thumbstrips_tempStopMouseScroll, true);

	if (thumbstrips_prefs.getBoolPref("startup.openTray") === true) 
    {
        thumbstrips_openTray();
    }
    
    if (thumbstrips_prefs.getBoolPref("startup.startRecording") === false)
    {
        thumbstrips_toggleRecording();
    } 
	
	//thumbstrips_checkFirstTimeStart();
	window.setTimeout(thumbstrips_checkFirstTimeStart, 10);
}

/**
 * Called when the browser is unloaded.
 */
function thumbstrips_unload() 
{
	// TODO save the filmstrip session upon exiting
	// Scott added 3/30/07
	// When the browser is unloaded, save the filmstrip to a file
	thumbstrips_saveHistoryBrowserUnload();

    var sortManager = new thumbstripsSortManager();
    if(sortManager.GetSortMode()==sortModeManually)
    {
        sortManager.SetSortingPreferences(false, false, false, true, false);
    }
    sortManager = null;
    	
	// Remove all listeners
	gBrowser.removeProgressListener(thumbstrips_listener);
	Components.classes["@mozilla.org/preferences-service;1"].
			getService(Components.interfaces.nsIPrefBranchInternal).removeObserver("thumbstrips.", thumbstrips_listener);
	
	window.clearInterval(thumbstrips_timeUpdater);
	
	thumbstrips_box.removeEventListener("overflow", thumbstrips_addScrollbar, true);
	thumbstrips_box.removeEventListener("underflow", thumbstrips_removeScrollbar, true);
//	thumbstrips_box.removeEventListener("overflowchanged", thumbstrips_changeScrollbar, true);
	
	if (thumbstrips_prefs.getBoolPref("options.pause_switch") === true) 
	{
		window.removeEventListener("blur", thumbstrips_tempStopRecording, true);
	}
	
	window.removeEventListener("blur", thumbstrips_tempStopMouseScroll, true);	
}

function thumbstrips_checkFirstTimeStart() 
{
	//alert("Enter first time launch");
	
	// we need to use timers for a few things because when you install an
	// extension, Firefox gives the user the option of restarting, and doing so
	// messes up us trying to open a new tab, etc.
	
	//var firstTime = thumbstrips_prefs.getBoolPref("main.first_time");
	
	//if (firstTime === false) {
//		window.removeEventListener("load", thumbstrips_launchHelp, true);
	//	return;
	//}
	
	//new
	var rdfs = Components.classes["@mozilla.org/rdf/rdf-service;1"]
				.getService(Components.interfaces.nsIRDFService);

	var ds = Components.classes["@mozilla.org/extensions/manager;1"]
				.getService(Components.interfaces.nsIExtensionManager).datasource;

	var trueVersion = ds.GetTarget(rdfs.GetResource("urn:mozilla:item:ilab@intuit"),
					rdfs.GetResource("http://www.mozilla.org/2004/em-rdf#version"), true)
					.QueryInterface(Components.interfaces.nsIRDFLiteral).Value;
	
	var prefVersion = thumbstrips_prefs.getCharPref("main.version");
	
	if (trueVersion.toString() === prefVersion.toString()) 
	{
		return;
	}
	//end new
	
	// Default is to show message for auto save on browser close
	thumbstrips_prefs.setBoolPref("autosave.show_message",true);
		
	// display welcome page
	// User is updating, show the update page, otherwise this a new install, show install page
	if(prefVersion.toString() != '' && prefVersion.toString() != trueVersion.toString()) 
	{
		window.setTimeout(thumbstrips_launchUpdatePage, 1000);
	}
	else 
	{
		window.setTimeout(thumbstrips_launchFirstTime, 1000);
	}
		
	// add toolbar button
	
	var toolbox = document.getElementById("navigator-toolbox");
	var toolboxDocument = toolbox.ownerDocument;
	//var hasThumbstripsButton = false;
	
	// new
	try 
	{
		addButton(["thumbstrips_openButtonOn"], "urlbar-container");
	} 
	catch (e) 
	{
		thumbstrips_log("error adding toolbar buttons:");
		thumbstrips_log(e);
	}
	
	//thumbstrips_openButton = document.getElementById("thumbstrips_openButtonOn");
	// renaming this variable fixes the first time launch bug with the toolbar button 
	// not being depressed and resize thumbnails not working
	thumbstrips_button = document.getElementById("thumbstrips_openButtonOn");
	
	function addButton(ids, before) 
	{
		var hasButton = false;
		
		for (var i = 0; i < toolbox.childNodes.length; ++i) 
		{
			var toolbar = toolbox.childNodes[i];
	
			if (toolbar.localName === "toolbar" && toolbar.getAttribute("customizable") === "true") 
			{
				if (toolbar.currentSet.indexOf(ids[0]) >= 0) 
				{
					hasButton = true;
				}
			}
		}
		
		if (hasButton === false) 
		{
			for (var i = 0; i < toolbox.childNodes.length; i++) 
			{
				var toolbar = toolbox.childNodes[i];
				
				if (toolbar.localName === "toolbar" && toolbar.getAttribute("customizable") === "true" && toolbar.id === "nav-bar") 
				{
					var newSet = "";
					var child = toolbar.firstChild;
					
					while (child) 
					{
						if (hasButton === false && child.id === before) 
						{
							newSet += (ids.toString() + ",");
							thumbstrips_log("newSet = " + newSet);
							hasButton = true;
						}
						
						newSet += child.id + ","
						child = child.nextSibling;
					}
				
					newSet = newSet.substring(0, newSet.length - 1);
	    		
	    			toolbar.currentSet = newSet;
	    			toolbar.setAttribute("currentset", newSet);
	    			
	    			toolboxDocument.persist(toolbar.id, "currentset");
	    		
	    			try 
	    			{
		    			BrowserToolboxCustomizeDone(true);
	    			} 
	    			catch (e) 
	    			{
	    				thumbstrips_log("error calling BrowserToolboxCustomizeDone:");
	    				thumbstrips_log(e);
	    			}
	    		
	    			break; 
				}
			}
		}
	}
	// end new	
	
	var resetPrefs = function() 
	{
		//thumbstrips_prefs.setBoolPref("main.first_time", false);
		thumbstrips_prefs.setCharPref("main.version", trueVersion.toString());
	}
	
	window.setTimeout(resetPrefs, 5000);
	
	thumbstrips_openTray();
}


function thumbstrips_getLocaleStrings() {
	
	var stringBundle = document.getElementById("thumbstrips_mainOverlayStringBundle");
	
	function get(key) {
		return stringBundle.getString(key);
	}
	
	// Locale strings - recording
	thumbstrips_recordingStopLabel = get("recordingStopLabel");
	thumbstrips_recordingStopTooltiptext = get("recordingStopTooltiptext");
	thumbstrips_recordingStartLabel = get("recordingStartLabel");
	thumbstrips_recordingStartTooltiptext = get("recordingStartTooltiptext");
	
	// Locale strings - searching/filtering
	thumbstrips_defaultSearchTerm = get("defaultSearchTerm");
	thumbstrips_contentButtonAllLabel = get("contentButtonAllLabel");
	thumbstrips_contentButtonFilteredLabel = get("contentButtonFilteredLabel");
	thumbstrips_contentAllLabel = get("contentAllLabel");
	
	// Locale strings - scrolling
	thumbstrips_rewindingStatus = get("rewindingStatus");
	thumbstrips_fforwardingStatus = get("fforwardingStatus");
	thumbstrips_pausedStatus = get("pausedStatus");
	
	// Locale strings - node details
	thumbstrips_deleteLabel = get("deleteLabel");
	thumbstrips_deleteTooltiptext = get("deleteTooltiptext");
	thumbstrips_propsLabel = get("propsLabel");
	thumbstrips_propsTooltiptext = get("propsTooltiptext");
	thumbstrips_nowLabel = get("nowLabel");
	
	// Locale strings - save/load
	thumbstrips_alertSaved = get("alertSaved");
	thumbstrips_errorInvalidFileName = get("errorInvalidFileName");
	thumbstrips_errorUnableToSave = get("errorUnableToSave");
	thumbstrips_errorInvalidFile = get("errorInvalidFile");
	thumbstrips_errorUnableToLoad = get("errorUnableToLoad");

    thumbstrips_thumbnailCommentMenuItemLabel = get("thumbnailCommentMenuLabel");
    thumbstrips_thumbnailCommentMenuToolTip = get("thumbnailCommentMenuToolTip");	
}


function thumbstrips_launchHelp() 
{
	var url = "chrome://thumbstrips/content/welcome.html";
	var browser = document.getElementById("content");
	var tab = browser.addTab(url);
	
	browser.selectedTab = tab;
}


function thumbstrips_launchFeedback() 
{
	var url = "http://innovation.intuit.com/blog/thumbstrips_feedback.php";
	var browser = document.getElementById("content");
	var tab = browser.addTab(url);
	
	browser.selectedTab = tab;
}


function thumbstrips_launchFirstTime() 
{
	var url = "chrome://thumbstrips/content/firstlaunch.html";
	var browser = document.getElementById("content");
	var tab = browser.addTab(url);
	
	browser.selectedTab = tab;
}


function thumbstrips_launchUpdatePage() 
{
	var url = "chrome://thumbstrips/content/updateinfo.html";
	var browser = document.getElementById("content");
	var tab = browser.addTab(url);
	
	browser.selectedTab = tab;
}

function thumbstrips_newCanvas(id) 
{
	var thumb = document.createElementNS("http://www.w3.org/1999/xhtml", "canvas");
	
	thumb.setAttribute("class", thumbstrips_thumbnailClass);
	thumb.setAttribute("id", thumbstrips_thumbnailClass + id);
	thumb.setAttribute("flex", 0);
	
	thumb.height = thumbstrips_prefs.getIntPref("style.thumb_max_height");
	thumb.displayHeight = thumbstrips_currentHeight;
	
	thumb.style.height = thumb.displayHeight + "px";
	thumb.style.minHeight = thumb.style.height;
	thumb.style.maxHeight = thumb.style.height;
	
	thumb.width = 0;
	thumb.displayWidth = 0;
	
	thumb.style.width = thumb.displayWidth + "px";
	thumb.style.minWidth = thumb.style.width;
	thumb.style.maxWidth = thumb.style.width;
	
	return thumb;
}


/**
 * Used by the filmstrip to initialize a new node.
 * 
 * If you have a dataURL for a thumbnail already, send it and this function
 * will copy the PNG data over onto the canvas, with correct scaling, etc.
 */

function thumbstrips_imageReloader(id, img, dataURL) 
{
	if (!img.complete) 
	{
		img.setAttribute("onload", "copyImage(\"" + id + "\", this, true);");
		img.setAttribute("onerror", "copyImage(\"" + id + "\", this, true);");
		img.src = dataURL;
		
		thumbstrips_log("image INCOMPLETE, reloading, id = " + id);
//		window.setTimeout(thumbstrips_imageReloader, 1000, id, img, dataURL);
		window.setTimeout(thumbstrips_copyImage, 1000, node.id, thumbstrips_emptyImage, true);
	}
	
//	thumbstrips_log("image complete, id = " + id);
}

function thumbstrips_togglePreference(pref) {
	var old = thumbstrips_prefs.getBoolPref(pref);
	thumbstrips_prefs.setBoolPref(pref, old === false);
}


function thumbstrips_showOptions() {
//	var page = thumbstrips_prefs.getIntPref("time.page_update_frequency");
//	var mouse = thumbstrips_prefs.getIntPref("time.mouse_update_frequency");
	
	window.openDialog("chrome://thumbstrips/content/optionsdialog.xul", "", "chrome,modal,centerscreen", thumbstrips_prefs, thumbstrips_GetDoNotRecordList());
}



// send stopRecording = true if you DON'T want to start recording again
// send aNodeList and aListOfIdLists if you are copying a filmstrip or loading a
// saved one, etc. (see filmstrip.js for more info)
function thumbstrips_makeNewFilmstrip(stopRecording, aNodeList, aListOfIdLists) 
{
	// what all needs to be done:
	// 1. make a new filmstrip object (delete the old)... draw it?
	// 2. clear the search box, and the search array
	// 3. clear the domain filter array
	// 4. start recording again if off (unless stopRecording is provided)
	// also need to temporarily disable recording while resetting things
	thumbstrips_wasRecording = thumbstrips_recording;
	
	if (thumbstrips_recording === true) 
	{
		thumbstrips_toggleRecording();
	}
	
	// after this point, thumbstrips_recording is always false
	
	thumbstripsSetCurrentWebPageNode(null);
	thumbstrips_GetFilmstrip().ClearContents();
    
    var renderer = new thumbstripsFilmstripRenderer();
    renderer.ClearContents();
    renderer = null;
        		
	// Initialize global variables
	thumbstrips_currentUrl = "";
	thumbstrips_deletedUrl = "";
	thumbstrips_statusBar = "";
	thumbstrips_domainFiltering = false;
	thumbstrips_clearSearch(true);
	thumbstrips_currentSearchPatterns = new Array();
	
	thumbstrips_drawFilmstrip();
	
	if (stopRecording) 
	{
		thumbstrips_newInterrupted = true;
		return;
	}
	
	if(thumbstrips_wasRecording==true)
    {
    	thumbstrips_toggleRecording();
    }
}




function thumbstrips_toggleRecording() 
{
	var img = document.getElementById("thumbstrips_sbImage");
	var view = document.getElementById("thumbstrips_viewRecordingMenuItem");
	var recordingOnMenuItem = document.getElementById("thumbstrips_toggleRecordingOnMenuItem");
	var recordingOffMenuItem = document.getElementById("thumbstrips_toggleRecordingOffMenuItem");
	var recordingOnButton = document.getElementById("thumbstrips_menuRecordButtonOn");
	var recordingOffButton = document.getElementById("thumbstrips_menuRecordButtonOff");
	
	if (thumbstrips_recording === true) 
	{
		if (img) 
		{
			img.setAttribute("src", "chrome://thumbstrips/skin/filmstrip_small_off.png");
		}
		
		if (view) 
		{
			view.setAttribute("label", thumbstrips_recordingStartLabel);
			view.setAttribute("tooltiptext", thumbstrips_recordingStartTooltiptext);
		}
				
		recordingOffMenuItem.hidden = false;
		recordingOnMenuItem.hidden = true;
			    
	    recordingOffButton.hidden = false;
	    recordingOnButton.hidden = true;
		
		thumbstrips_recording = false;
		thumbstrips_clearUpdaters();
		thumbstrips_currentUrl = "";
		thumbstrips_currentNode = null;
		thumbstrips_updateTimes();
	} 
	else 
	{
		if (img) 
		{
			img.setAttribute("src", "chrome://thumbstrips/skin/filmstrip_small_on.png");
		}
		
		if (view) 
		{
			view.setAttribute("label", thumbstrips_recordingStopLabel);
			view.setAttribute("tooltiptext", thumbstrips_recordingStopTooltiptext);
		}    
	    		
		recordingOffMenuItem.hidden = true;
		recordingOnMenuItem.hidden = false;
		    
	    recordingOffButton.hidden = true;
	    recordingOnButton.hidden = false;
	
		thumbstrips_recording = true;
        thumbstrips_resetUpdaters();	
	}
}

function thumbstrips_tempStopRecording() 
{
	if (thumbstrips_recording === true) 
	{
		thumbstrips_toggleRecording();
		window.addEventListener("focus", thumbstrips_tempStartRecording, true);
	}
}

function thumbstrips_tempStartRecording() 
{
	// don't start recording if we're in the middle of a print preview
	// (see printpreview.js -- this is very much a hack)
	if (thumbstrips_printPreviewing === true) 
	{
		thumbstrips_ppInterrupted = true;
		return;
	}
	
	if (thumbstrips_newInterrupted === true) 
	{
		thumbstrips_newInterrupted = false;
		window.removeEventListener("focus", thumbstrips_tempStartRecording, true);
		return;
	}
	
	if (thumbstrips_recording === false) 
	{
		thumbstrips_toggleRecording();
		window.removeEventListener("focus", thumbstrips_tempStartRecording, true);
	}
}

function thumbstrips_togglePauseSwitchPreference() {
	thumbstrips_togglePreference("options.pause_switch");
}

function thumbstrips_setPauseSwitch(value) {
	if (value === true) { // currently off, turn it on
		window.addEventListener("blur", thumbstrips_tempStopRecording, true);
	} else {
		window.removeEventListener("blur", thumbstrips_tempStopRecording, true);
	}
	
	var item = document.getElementById("thumbstrips_pauseSwitchMenuItem");
	item.setAttribute("checked", value);
}



// returns an array of three boolean values based on prefs:
// [ firstVisit?, lastVisit?, or everyVisit ]
// technically, exactly one should be true, but if the prefs are wrong,
// this function will be smart and prioritize
function thumbstrips_getSortingArray() 
{
	var tmpArray = new Array();
	
	tmpArray[0] = thumbstrips_prefs.getBoolPref("sorting.first_visit");
	tmpArray[1] = thumbstrips_prefs.getBoolPref("sorting.last_visit");
	tmpArray[2] = thumbstrips_prefs.getBoolPref("sorting.every_visit");
	tmpArray[3] = thumbstrips_prefs.getBoolPref("sorting.manual");
	
	if(tmpArray[3] === true)
	{
		tmpArray[0] = false;
		tmpArray[1] = false;	
		tmpArray[2] = false;	
	}
	else if (tmpArray[2] === true) 
	{
		tmpArray[0] = false;
		tmpArray[1] = false;
	} 
	else if (tmpArray[1] == true) 
	{
		tmpArray[0] = false;
	} 
	else 
	{
		tmpArray[0] = true;
	}
	
	return tmpArray;
}


function thumbstrips_launchIIComSite() {
	var url = "http://innovation.intuit.com/blog/browse-for-thumbstrips";
	var browser = document.getElementById("content");
	var tab = browser.addTab(url);
	
	browser.selectedTab = tab;
}


function pleaseWaitLoad() {
	try {
		var dialog = document.getElementById("please-wait-dialog");
        setTimeout(function() {
			try { 
				//var chromeRegistry = Components.classes["@mozilla.org/chrome/chrome-registry;1"].
			 	//getService(Components.interfaces.nsIXULChromeRegistry);
				//chromeRegistry.reloadChrome(); 
				window.close(); 
			}
			catch(e) {
				alert(e)
			}
		},1000);
	}
	catch(e) {
		alert("in pleasewaitload "+e);
	}
}

function loadingPleaseWait() {
	try {
		var dialog = document.getElementById("loading-dialog");
        setTimeout(function() {
			try { 
				//var chromeRegistry = Components.classes["@mozilla.org/chrome/chrome-registry;1"].
			 	//getService(Components.interfaces.nsIXULChromeRegistry);
				//chromeRegistry.reloadChrome(); 
				window.close(); 
			}
			catch(e) {
				alert(e)
			}
		},1000);
	}
	catch(e) {
		alert("in loadingpleasewait "+e);
	}
}

function thumbstrips_onBeforeUnload()
{
    if(thumbstrips_recording==true)
    {
        if(hasBeenOnPageForMinimumTime==true)
        {
            if(!thumbstrips_GetDoNotRecordList().IsInList(GetCurrentUrl(), false))
            {       
                var currentNode = thumbstripsGetCurrentWebPageNode();
            
                if(currentNode==null)
	            {
	                var filmstripManager = thumbstrips_GetFilmstrip();

	                currentNode = filmstripManager.GetWebPageNodeByUrl(GetCurrentUrl());
	    
	                if(currentNode==null)
	                {
	                    currentNode = filmstripManager.AddOrUpdateWebPageNode(GetCurrentUrl());
	                    filmstripManager.UpdateWebsiteNode(currentNode);
                    }
        	        
	                thumbstripsSetCurrentWebPageNode(currentNode);
	            }
	        
	            currentNode.UpdateContents(content);
	            thumbstrips_GetFilmstrip().UpdateWebsiteNode(currentNode, GetCurrentUrl());
            
                currentNode = null;
                renderer = null;
            }
        }
    }
}

function thumbstripsRecordingButtonMouseOver(isMouseOver)
{
    var recordingButton = document.getElementById("thumbstrips_menuRecordButtonOn");
    
    if(isMouseOver)
    {
        recordingButton.label = "stop recording";
    }
    else
    {
        recordingButton.label = "recording";    
    }
}

function HandleMinimumPageTimeEvent()
{
    hasBeenOnPageForMinimumTime = true;

    var url = GetCurrentUrl();

	if(thumbstrips_recording==true)
	{
        if(!thumbstrips_GetDoNotRecordList().IsInList(url, false))
        {        
     	    // Add (and initialize) or update the node for this page
	        var currentNode = thumbstrips_GetFilmstrip().AddOrUpdateWebPageNode(url, true);

            thumbstripsSetCurrentWebPageNode(currentNode);	        
	        currentNode.UpdateContents(content);
       	    thumbstrips_GetFilmstrip().UpdateWebsiteNode(currentNode, url);
	        
            var renderer = new thumbstripsFilmstripRenderer();
            renderer.Draw(true);
            renderer = null;
            
            thumbstrips_resetUpdaters();
        }
    }
    
    thumbstrips_skipToCurrent();
}