// ********************************************************************************** //
// The contents of this file are subject to the Mozilla Public License Version 1.1    //
// (the "License"); you may not use this file except in compliance with the License.  //
// You may obtain a copy of the License at http://www.mozilla.org/MPL/                //
//                                                                                    //
// Software distributed under the License is distributed on an "AS IS" basis,         //
// WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License for the  //
// specific language governing rights and limitations under the License.              //
//                                                                                    //
// The Original Code provided by Mozilla's Firefox is XUL, Javascript, and CSS.       // 
// All Rights Reserved. 
// Contributor - Intuit Inc. (c) 2007                                                 //
// ********************************************************************************** //

// -- INITIALIZATION -- //

var doNotRecordListFileName = "thumbstripsDoNotRecordList.xml";
/**
 * An object that listens for changes in browser location, preferences, etc.
 */
function thumbstripsDoNotRecordList()
{
    this.m_doNotRecordItems = new Array();
    this.m_doNotRecordListFile = null;
}

thumbstripsDoNotRecordList.prototype.GetAllItems = thumbstripsDoNotRecordListGetAllItems;
thumbstripsDoNotRecordList.prototype.UpdateSSLPreference = thumbstripsDoNotRecordListUpdateSSLPreference;
thumbstripsDoNotRecordList.prototype.Initialize = thumbstripsDoNotRecordListInitialize;
thumbstripsDoNotRecordList.prototype.Load = thumbstripsDoNotRecordListLoad;
thumbstripsDoNotRecordList.prototype.Save = thumbstripsDoNotRecordListSave;
thumbstripsDoNotRecordList.prototype.IsInList = thumbstripsDoNotRecordListIsInList;
thumbstripsDoNotRecordList.prototype.AddToDoNotRecordList = thumbstripsDoNotRecordListAddToDoNotRecordList;
thumbstripsDoNotRecordList.prototype.DoesFileExist = thumbstripsDoNotRecordListDoesFileExist;
thumbstripsDoNotRecordList.prototype.RemoveFromList = thumbstripsDoNotRecordListRemoveFromList;

function thumbstripsDoNotRecordListDoesFileExist(parentDirectory, fileName)
{
    var retVal = false;
    
    var targetFile = Components.classes["@mozilla.org/file/directory_service;1"]
                   .getService(Components.interfaces.nsIProperties)
                   .get("UChrm", Components.interfaces.nsIFile);
    
    // History file stored at <user's chrome>\filmstrips\<file_name><file_ext>
    targetFile.append(parentDirectory, fileName);

    targetFile.append(fileName);
    
    if(targetFile.exists()) 
    {
        retVal = true;
    }
    
    return retVal;
}

function thumbstripsDoNotRecordListInitialize(addRootNode)
{
    this.m_doNotRecordListFile = new thumbstripsXmlHelper(); 

    if(addRootNode==true)
        this.m_doNotRecordListFile.Initialize("","DoNotRecordList");  
    else
        this.m_doNotRecordListFile.Initialize("","");     
}

function thumbstripsDoNotRecordListLoad()
{
    if(this.DoesFileExist(thumbstrips_xmlDirectory, doNotRecordListFileName))
    {
        this.Initialize(false);
        this.m_doNotRecordListFile.Load(thumbstrips_xmlDirectory, doNotRecordListFileName);
    }
    else
    {
        this.Initialize(true);
        this.UpdateSSLPreference(thumbstrips_prefs.getBoolPref("recording.doNotRecordSecureSites"));
        this.AddToDoNotRecordList("about:");
        this.AddToDoNotRecordList("wyciwyg:");     
    }
}
    
function thumbstripsDoNotRecordListSave()
{
    if(this.m_doNotRecordListFile!=null)
    {
        this.m_doNotRecordListFile.Save(thumbstrips_xmlDirectory, doNotRecordListFileName);
    }
}
    
function thumbstripsDoNotRecordListIsInList(targetUrl, matchExactly)
{   
    var retVal = false;
    
    if(this.m_doNotRecordListFile!=null)
    {
        var doNotRecordListNodes = this.m_doNotRecordListFile.m_xmlData.getElementsByTagName("DoNotRecordItem");

        if(matchExactly==false)
        {                   
            for(var i = 0; i < doNotRecordListNodes.length; i++)
            {                
                if(targetUrl.indexOf(doNotRecordListNodes[i].firstChild.nodeValue) >= 0)
                {
                    retVal = true;
                    break;
                }
            }
        }
        else
        {
            for(var i = 0; i < doNotRecordListNodes.length; i++)
            {
                if(doNotRecordListNodes[i].firstChild.nodeValue==targetUrl)
                {
                    retVal = true;
                    break;
                }
            }        
        }
    }
        
    return retVal;
}

function thumbstripsDoNotRecordListAddToDoNotRecordList(targetUrl)
{    
    if(this.m_doNotRecordListFile!=null)
    {
        if(!this.IsInList(targetUrl, true))
        {
            this.m_doNotRecordListFile.AddTextNode("DoNotRecordList", "DoNotRecordItem", targetUrl);
            this.Save();
        }
    }
}

function thumbstripsDoNotRecordListRemoveFromList(targetUrl)
{
    if(this.m_doNotRecordListFile!=null)
    {
        parentItem = this.m_doNotRecordListFile.m_xmlData.getElementsByTagName("DoNotRecordList");
        doNotRecordListNodes = parentItem[0].getElementsByTagName("DoNotRecordItem");

        for(var i = doNotRecordListNodes.length - 1; i > -1; i--)
        {
            if(doNotRecordListNodes[i].firstChild.nodeValue==targetUrl)
            {   
                parentItem[0].removeChild(doNotRecordListNodes[i]);
                break;
            }
        }        
    }
}

function thumbstripsDoNotRecordListUpdateSSLPreference(doNotRecordSecureSites)
{
    if(doNotRecordSecureSites===true)
    {
        this.AddToDoNotRecordList("https://");
    }
    else
    {
        this.RemoveFromList("https://");
    }
}

function thumbstripsDoNotRecordListGetAllItems()
{
    var retVal = new Array();
    
    if(this.m_doNotRecordListFile!=null)
    {
        doNotRecordListNodes = this.m_doNotRecordListFile.m_xmlData.getElementsByTagName("DoNotRecordItem");

        for(var i = 0; i < doNotRecordListNodes.length; i++)
        {
            retVal[i] = doNotRecordListNodes[i].firstChild.nodeValue;
        }    
    }
    
    return retVal;
}

var thumbstrips_doNotRecordList;

function thumbstrips_GetDoNotRecordList()
{	
	if(thumbstrips_doNotRecordList==null)
	{
	    thumbstrips_doNotRecordList = new thumbstripsDoNotRecordList();
	    thumbstrips_doNotRecordList.Load();	    
	}
    
    return thumbstrips_doNotRecordList;
}
        
function thumbstripsHandleAddToDoNotRecordList()
{
    thumbstrips_GetDoNotRecordList().AddToDoNotRecordList(GetCurrentUrl());
}

function thumbstripsShowDoNotRecordDialog()
{
    var targetUrl = GetCurrentUrl();	
	window.openDialog("chrome://thumbstrips/content/DoNotRecordDialog.xul", "", "chrome,modal,centerscreen", targetUrl, thumbstrips_GetDoNotRecordList());
}

function thumbstripsShowViewDoNotRecordDialog()
{
	window.openDialog("chrome://thumbstrips/content/ViewDoNotRecordDialog.xul", "", "chrome,modal,centerscreen", thumbstrips_prefs, thumbstrips_GetDoNotRecordList());
}