// ********************************************************************************** //
// The contents of this file are subject to the Mozilla Public License Version 1.1    //
// (the "License"); you may not use this file except in compliance with the License.  //
// You may obtain a copy of the License at http://www.mozilla.org/MPL/                //
//                                                                                    //
// Software distributed under the License is distributed on an "AS IS" basis,         //
// WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License for the  //
// specific language governing rights and limitations under the License.              //
//                                                                                    //
// The Original Code provided by Mozilla's Firefox is XUL, Javascript, and CSS.       // 
// Contributor - Intuit Inc. (c) 2007                                                 //
// ********************************************************************************** //

// webpagenode.js

var thumbstrips_WN_CHECK_REP = true;

function thumbstripsWebPageThumbnailNode(url, pageThumbnail, scrollX, scrollY, visitTimeInMilliseconds) 
{
    this.m_title = "";
    
	this.m_url = "";
	
	if(url!=null)
	    this.m_url = url;

	this.m_domain = thumbstrips_trimDomainFromUrl(this.m_url);
	
	if(pageThumbnail)
	{
	    this.m_pageThumbnail = pageThumbnail;
	}
	else
	{
    	this.m_pageThumbnail = new thumbstripsThumbnail();
        this.m_pageThumbnail.InitializeFromSourceUrl(url);
    }
    
	this.m_pageText = "";
    
    this.m_scrollX = 0;
    
    if(scrollX!=null)
        this.m_scrollX = scrollX;
        
    if(scrollY = null)
        this.m_scrollY = scrollY;

    this.m_visitTimeInMilliseconds = 0;
    
    if(visitTimeInMilliseconds!=null)
        this.m_visitTimeInMilliseconds = visitTimeInMilliseconds;
        
    this.m_lastUpdateDate = new Date();
    
    this.m_comment = "";
}

thumbstripsWebPageThumbnailNode.prototype.Destroy = thumbstripsWebPageThumbnailNodeDestroy;
thumbstripsWebPageThumbnailNode.prototype.ReadFromXml = thumbstripsWebPageThumbnailNodeReadFromXml;
thumbstripsWebPageThumbnailNode.prototype.UpdateContents = thumbstripsWebPageThumbnailNodeUpdateContents;
thumbstripsWebPageThumbnailNode.prototype.CapturePageText = thumbstripsWebPageThumbnailNodeCapturePageText;
thumbstripsWebPageThumbnailNode.prototype.UpdatePageScroll = thumbstripsWebPageThumbnailNodeUpdatePageScroll;

function thumbstripsWebPageThumbnailNodeDestroy()
{
    if(this.m_pageThumbnail!=null)
    {
        this.m_pageThumbnail.Destroy();
        this.m_pageThumbnail = null;
    }
    
    if(this.m_lastUpdateDate!=null)
    {
        this.m_lastUpdateDate = null;
    }
}

function thumbstripsWebPageThumbnailNodeReadFromXml(sourceElement)
{
    this.m_url = sourceElement.getAttribute("SourceUrl");
    this.m_domain = sourceElement.getAttribute("Domain");
    this.m_lastUpdateDate = new Date(sourceElement.getAttribute("LastUpdate"));
        
    // create the page text node
    var pageTextNode = sourceElement.selectSingleNode("descendant::PageText");                
	this.m_pageText = "";	
    
    if(pageTextNode!=null)
    {
        var textNodes = pageTextNode.childNodes;
		
        for (var i = 0; i < textNodes.length; i++) 
	    {
	        this.m_pageText += thumbstrips_removeComments(textNodes[i].nodeValue);
        }        
    }
    
    // create the page thumbnail node
    var pageThumbnailNode = sourceElement.selectSingleNode("descendant::Thumbnail");                
    
    if(pageThumbnailNode!=null)
    {
        this.m_pageThumbnail = new thumbstripsThumbnail();
        this.m_pageThumbnail.InitializeFromDataUrl(this, pageThumbnailNode.firstChild.nodeValue);
    }
    
    // create the page thumbnail node
    var scrollXElement = sourceElement.selectSingleNode("descendant::ScrollX");                
    
    if(scrollXElement!=null)
    {
        this.m_scrollX = scrollXElement.firstChild.nodeValue;
    }
    else
    {
        this.m_scrollX = 0;
    }
    
    // create the page thumbnail node
    var scrollYElement = sourceElement.selectSingleNode("descendant::ScrollY");                
    
    if(scrollYElement!=null)
    {
        this.m_scrollY = scrollYElement.firstChild.nodeValue;
    }
    else
    {
        this.m_scrollY = 0;
    }
    
    var timeOnPageElement = sourceElement.selectSingleNode("descendant::TimeOnPage");                
    
    if(timeOnPageElement!=null)
    {
        this.m_visitTimeInMilliseconds = timeOnPageElement.firstChild.nodeValue;
    }
    else
    {
        this.m_visitTimeInMilliseconds = 0;
    }
    
    var commentElement = sourceElement.selectSingleNode("descendant::" + filmstripTag_ThumbnailComment);                
    
    if(commentElement!=null)
    {
        this.m_comment = commentElement.firstChild.nodeValue;
    }
    else
    {
        this.m_comment = "";
    }    
}

function thumbstripsWebPageThumbnailNodeUpdateContents(content)
{   
    this.m_title = content.document.title !== "" ? content.document.title : this.m_url;
    
    if(content.document!=null)
    {
        this.m_pageText = null;
        this.m_pageText = this.CapturePageText(content.document.body ? content.document.body : content.document);
    }
    else
    {
        if(this.m_pageText==null)
            this.m_pageText = "";
    }

    this.m_pageThumbnail.UpdateCanvas(this);
    this.UpdatePageScroll(content);
    
    this.m_lastUpdateDate = null;
    this.m_lastUpdateDate = new Date();
}    

function thumbstripsWebPageThumbnailNodeCapturePageText(contentNode)
{
	// recursive cases:
	
	// body, text, etc.: return textContent
	// frame, iframe: return textContent + f_cPT(frame.contentDocument.body)
	// frameset: return textContent + f_cPT(childNode[i]) for each i
	
	var retVal = "";
	
	// this should apply to HTMLBodyElement, Text, and others
	if (contentNode.textContent) 
	{
		retVal = contentNode.textContent;
	}
	
	if (contentNode instanceof HTMLFrameElement || contentNode instanceof HTMLIFrameElement) 
	{
		// don't know if this check is necessary, but just to be on the safe side...
		if (contentNode.contentDocument) 
		{
			retVal += " " + this.CapturePageText(contentNode.contentDocument.body ? contentNode.contentDocument.body : contentNode.contentDocument);
		}
	} 
	else if (contentNode instanceof HTMLFrameSetElement || contentNode instanceof XMLDocument) 
	{
		var nodes = contentNode.childNodes;
		
		for (var i = 0; i < nodes.length; i++) 
		{
			retVal += " " + this.CapturePageText(nodes.item(i));
		}
		
		nodes = null;
	}

    return thumbstrips_removeComments(retVal);
}

function thumbstripsWebPageThumbnailNodeUpdatePageScroll(pageContent)
{
    var wPage = pageContent.innerWidth - 16;
	var hPage = pageContent.innerHeight - 16;
		
	var sLeft = pageContent.pageXOffset;
	var sTop = pageContent.pageYOffset;
		
	if (!thumbstrips_tray.getAttribute("hidden")) 
	{
		var end = pageContent.innerHeight + pageContent.scrollMaxY;
		var trayHeight = thumbstrips_tray.boxObject.height;
			
		if (end < (hPage + trayHeight)) 
		{
			end = hPage + trayHeight;
		}
			
		var sMax = end - hPage - trayHeight;
			
		hPage += trayHeight;
				
		if (sTop > sMax) 
		{
			sTop = sMax;
		}
	}
	
	this.m_scrollX = sLeft;
	this.m_scrollY = sTop;
}




